import { GraphAnnotationEvent, GraphCanvasEvent, GraphEdgeEvent, GraphNodeEvent, GraphPortEvent } from "../common/GraphEvent.constant";
export declare type TSetData = React.Dispatch<React.SetStateAction<ICanvasData>>;
export interface ICanvasNode {
    shape?: string;
    x: number;
    y: number;
    name?: string;
    id: string;
    state?: GraphNodeState;
    isInSearchResults?: boolean;
    ports?: ICanvasPort[];
    data?: any;
    height?: number;
    width?: number;
}
export declare enum GraphEdgeState {
    default = "default",
    selected = "selected"
}
export interface ICanvasEdge {
    shape?: string;
    source: string;
    target: string;
    sourcePortId: string;
    targetPortId: string;
    id: string;
    state?: GraphEdgeState;
}
export interface ICanvasPort {
    id: string;
    name: string;
    shape?: string;
    position?: [number, number];
    state?: GraphPortState;
    connectState?: GraphPortConnectState;
    isInputDisabled?: boolean;
    isOutputDisabled?: boolean;
}
export interface ICanvasAnnotation {
    shape?: string;
    x: number;
    y: number;
    name?: string;
    id: string;
    state?: GraphNodeState;
    data?: any;
    height?: number;
    width?: number;
}
export declare enum GraphNodeState {
    default = "default",
    activated = "activated",
    selected = "selected",
    editing = "editing"
}
export declare enum GraphPortState {
    default = "default",
    selected = "selected",
    activated = "activated",
    connecting = "connecting"
}
export declare enum GraphPortConnectState {
    connectedAsSource = "connectedAsSource",
    connectedAsTarget = "connectingAsTarget"
}
export interface ICanvasData {
    nodes: ICanvasNode[];
    edges: ICanvasEdge[];
    annotations?: ICanvasAnnotation[];
}
export declare type GraphNodeEventProps = Record<GraphNodeEvent, (e: any, node: ICanvasNode) => void>;
export declare type GraphEdgeEventProps = Record<GraphEdgeEvent, (e: any, edge: ICanvasEdge) => void>;
export declare type GraphPortEventProps = Record<GraphPortEvent, (e: any, node: ICanvasNode, port: ICanvasPort) => void>;
export declare type GraphAnnotationEventProps = Record<GraphAnnotationEvent, (e: any, annotation: ICanvasAnnotation) => void>;
export declare type GraphCanvasEventProps = Record<GraphCanvasEvent, (e: any) => void>;
