import * as React from "react";
import { IGraphClipBoard } from "../built-in/defaultClipboard";
import { ICanvasAnnotation, ICanvasData, ICanvasEdge, ICanvasNode, ICanvasPort, IGraphProps, TSetData } from "../components";
import { ITheme } from "./ThemeContext";
interface IItemConfigArgs<T> {
    model: T;
    graphProps: IGraphProps;
    setData: TSetData;
    theme: ITheme;
}
export interface INodeDrawArgs extends IItemConfigArgs<ICanvasNode> {
}
export interface IRectConfig<T> {
    portShape?: string;
    getPorts?(args: Omit<INodeDrawArgs, "theme">): ICanvasPort[];
    render(args: IItemConfigArgs<T>): React.ReactNode;
    getStyle?(rect: T, theme: ITheme): React.CSSProperties;
    getMinWidth(rect: T): number;
    getMinHeight(rect: T): number;
}
export interface IEdgeDrawArgs extends IItemConfigArgs<ICanvasEdge> {
    x1: number;
    y1: number;
    x2: number;
    y2: number;
}
export interface IEdgeConfig {
    render(args: IEdgeDrawArgs): React.ReactNode;
    getStyle?(edge: ICanvasEdge, theme: ITheme): React.CSSProperties;
}
export interface IPortDrawArgs extends IItemConfigArgs<ICanvasPort> {
    data: ICanvasData;
    parentNode: ICanvasNode;
    x: number;
    y: number;
}
export interface IPortConfig {
    render(args: IPortDrawArgs): React.ReactNode;
    getIsConnectable(port: ICanvasPort, data: ICanvasData): boolean | undefined;
    getStyle?(port: ICanvasPort, data: ICanvasData, theme: ITheme): React.CSSProperties;
}
export interface IGraphConfig {
    registerNode(name: string, config: IRectConfig<ICanvasNode>): void;
    getNodeConfigByName(name: string): IRectConfig<ICanvasNode> | void;
    registerEdge(name: string, config: IEdgeConfig): void;
    getEdgeConfigByName(name: string): IEdgeConfig | void;
    registerPort(name: string, config: IPortConfig): void;
    getPortConfigByName(name: string): IPortConfig | void;
    registerAnnotation(name: string, config: IRectConfig<ICanvasAnnotation>): void;
    getAnnotationConfigByName(name: string): IRectConfig<ICanvasAnnotation> | void;
    registerClipboard(clipboard: IGraphClipBoard): void;
    getClipboard(): IGraphClipBoard;
}
export declare class GraphConfig implements IGraphConfig {
    private readonly nodeConfigList;
    private readonly edgeConfigList;
    private readonly portConfigList;
    private readonly annotationConfigList;
    private clipboard?;
    registerNode(name: string, config: IRectConfig<ICanvasNode>): void;
    getNodeConfigByName(name: string): IRectConfig<ICanvasNode> | void;
    registerEdge(name: string, config: IEdgeConfig): void;
    getEdgeConfigByName(name: string): IEdgeConfig | void;
    registerPort(name: string, config: IPortConfig): void;
    getPortConfigByName(name: string): IPortConfig | void;
    registerAnnotation(name: string, config: IRectConfig<ICanvasAnnotation>): void;
    getAnnotationConfigByName(name: string): IRectConfig<ICanvasAnnotation> | void;
    registerClipboard(clipboard: IGraphClipBoard): void;
    getClipboard(): IGraphClipBoard;
}
export declare const GraphConfigContext: React.Context<IGraphConfig>;
export {};
