import * as React from "react";
import { ICanvasAnnotation, ICanvasData, ICanvasEdge, ICanvasNode, ICanvasPort, TSetData } from "../components";
import { IZoomPanSettings, TSetZoomPanSettings } from "../utils/zoomAndPan";
import { IGraphConfig } from "./GraphConfigContext";
import { IPanelContext } from "./PanelContext";
export interface IPropsAPI {
    init(_setData: TSetData, _getData: () => ICanvasData, svgRef: React.RefObject<SVGSVGElement>, zoomPanSettings: IZoomPanSettings, setZoomPanSettings: TSetZoomPanSettings, graphConfig: IGraphConfig, panelContext: IPanelContext): void;
    getNodeById(id: string): ICanvasNode | void;
    read(data: ICanvasData): void;
    save(): ICanvasData;
    setData(data: ICanvasData): void;
    getData(): ICanvasData;
    addNode(node: ICanvasNode): void;
    setSelected(nodeId: string): void;
    addEdge(edge: ICanvasEdge): void;
    updateNode(id: string, patch: Partial<ICanvasNode>): ICanvasNode | false;
    deletePort(portId: string, nodeId: string): void;
    addPort<P extends ICanvasPort>(nodeId: string, port: P): void;
    delete(): void;
    zoom(scale: number): void;
    pan(dx: number, dy: number): void;
    resetZoom(): void;
    zoomTo(scale: number): void;
    zoomToFit(): void;
    copy(): void;
    paste(x?: number, y?: number): void;
    addAnnotation(annotation: ICanvasAnnotation): void;
    undo(): void;
    redo(): void;
    markSearchResults(matchesIds: string[]): void;
    openSidePanel(name: string, data?: any): void;
    dismissSidePanel(): void;
    getVisiblePanelName(): string | void;
    scrollIntoView(x: number, y: number): void;
    getBoundaryPoints(): {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
}
export interface IPropsAPIContext {
    propsAPI: IPropsAPI;
}
export declare class PropsAPI implements IPropsAPI {
    private _setData;
    private _getData;
    private _svgRef;
    private _zoomPanSettings;
    private _setZoomPanSettings;
    private _graphConfig;
    private _panelContext;
    init(_setData: TSetData, _getData: () => ICanvasData, svgRef: React.RefObject<SVGSVGElement>, zoomPanSettings: IZoomPanSettings, setZoomPanSettings: TSetZoomPanSettings, graphConfig: IGraphConfig, panelContext: IPanelContext): void;
    getNodeById(id: string): ICanvasNode | void;
    setData(data: ICanvasData): void;
    read(data: ICanvasData): void;
    getData(): ICanvasData;
    save(): ICanvasData;
    addNode(node: ICanvasNode): void;
    addEdge(edge: ICanvasEdge): void;
    updateNode(id: string, patch: Partial<ICanvasNode>): ICanvasNode | false;
    deletePort(portId: string, nodeId: string): void;
    addPort<P extends ICanvasPort>(nodeId: string, port: P): void;
    setSelected(nodeId: string): void;
    delete(): void;
    zoom(scale: number): void;
    pan(dx: number, dy: number): void;
    resetZoom(): void;
    zoomTo(scale: number): void;
    zoomToFit(): void;
    copy(): void;
    paste(x?: number, y?: number): void;
    addAnnotation(annotation: ICanvasAnnotation): void;
    redo(): void;
    undo(): void;
    markSearchResults(matchesIds: string[]): void;
    openSidePanel(name: string, data?: any): void;
    dismissSidePanel(): void;
    getVisiblePanelName(): string | void;
    scrollIntoView(x: number, y: number): void;
    getBoundaryPoints(): {
        minX: number;
        minY: number;
        maxX: number;
        maxY: number;
    };
}
export declare const PropsAPIContext: React.Context<IPropsAPIContext>;
